<?php
/*****************************************************************************
 * ManageAlbums.php
 * Contains the controller for admin album management.
 *
 * Kabuki CMS (C) 2013-2017, Aaron van Geffen
 *****************************************************************************/

class ManageAlbums extends HTMLController
{
	public function __construct()
	{
		// Ensure it's just admins at this point.
		if (!Registry::get('user')->isAdmin())
			throw new NotAllowedException();

		$options = [
			'form' => [
				'action' => BASEURL . '/editalbum/',
				'method' => 'get',
				'class' => 'col-md-6 text-end',
				'buttons' => [
					'add' => [
						'type' => 'submit',
						'caption' => 'Add new album',
					],
				],
			],
			'columns' => [
				'id_album' => [
					'value' => 'id_tag',
					'header' => 'ID',
					'is_sortable' => true,
				],
				'tag' => [
					'header' => 'Album',
					'is_sortable' => true,
					'parse' => [
						'link' => BASEURL . '/editalbum/?id={ID_TAG}',
						'data' => 'tag',
					],
				],
				'slug' => [
					'header' => 'Slug',
					'is_sortable' => true,
					'parse' => [
						'link' => BASEURL . '/editalbum/?id={ID_TAG}',
						'data' => 'slug',
					],
				],
				'count' => [
					'header' => '# Photos',
					'is_sortable' => true,
					'value' => 'count',
				],
			],
			'start' => !empty($_GET['start']) ? (int) $_GET['start'] : 0,
			'sort_order' => !empty($_GET['order']) ? $_GET['order'] : null,
			'sort_direction' => !empty($_GET['dir']) ? $_GET['dir'] : null,
			'title' => 'Manage albums',
			'no_items_label' => 'No albums meet the requirements of the current filter.',
			'items_per_page' => 9999,
			'index_class' => 'col-md-6',
			'base_url' => BASEURL . '/managealbums/',
			'get_data' => function($offset = 0, $limit = 9999, $order = '', $direction = 'up') {
				if (!in_array($order, ['id_tag', 'tag', 'slug', 'count']))
					$order = 'tag';
				if (!in_array($direction, ['up', 'down']))
					$direction = 'up';

				$rows = PhotoAlbum::getHierarchy($order, $direction);

				return [
					'rows' => $rows,
					'order' => $order,
					'direction' => ($direction == 'up' ? 'up' : 'down'),
				];
			},
			'get_count' => function() {
				return 9999;
			}
		];

		$table = new GenericTable($options);
		parent::__construct('Album management - Page ' . $table->getCurrentPage() .' - ' . SITE_TITLE);
		$this->page->adopt(new TabularData($table));
	}
}
